@@ -16,11 +16,12 @@ from utilities.forms import (
 )
 
 from netbox_storage.models import Drive
-from virtualization.models import Cluster, VirtualMachine
+from virtualization.models import Cluster, ClusterType, VirtualMachine
 
 
 class DriveForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
+    # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
     size = IntegerField(
         label="Size (GB)",
         help_text="The size of the drive e.g. 25",
@@ -30,6 +31,9 @@ class DriveForm(NetBoxModelForm):
         queryset=Cluster.objects.all(
             # type__pk=ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
         ),
+        query_params={
+            'type_id': 'ct',
+        },
         help_text="The Storage Cluster of the drive",
     )
     virtual_machine = DynamicModelChoiceField(
