@@ -46,28 +46,6 @@ filesystem_menu_item = PluginMenuItem(
     ),
 )
 
-linuxvolume_menu_item = PluginMenuItem(
-    link="plugins:netbox_storage:linuxvolume_list",
-    link_text="Linux Volume",
-    permissions=["netbox_storage.disk_view"],
-    buttons=(
-        PluginMenuButton(
-            "plugins:netbox_storage:linuxvolume_add",
-            "Add",
-            "mdi mdi-plus-thick",
-            ButtonColorChoices.GREEN,
-            permissions=["netbox_storage.add_disk"],
-        ),
-        PluginMenuButton(
-            "plugins:netbox_storage:linuxvolume_import",
-            "Import",
-            "mdi mdi-upload",
-            ButtonColorChoices.CYAN,
-            permissions=["netbox_storage.add_disk"],
-        ),
-    ),
-)
-
 
 partition_menu_item = PluginMenuItem(
     link="plugins:netbox_storage:partition_list",
@@ -113,6 +91,50 @@ physicalvolume_menu_item = PluginMenuItem(
     ),
 )
 
+volumegroup_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:volumegroup_list",
+    link_text="Volume Group",
+    permissions=["netbox_storage.disk_view"],
+    buttons=(
+        PluginMenuButton(
+            "plugins:netbox_storage:volumegroup_add",
+            "Add",
+            "mdi mdi-plus-thick",
+            ButtonColorChoices.GREEN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+        PluginMenuButton(
+            "plugins:netbox_storage:volumegroup_import",
+            "Import",
+            "mdi mdi-upload",
+            ButtonColorChoices.CYAN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+    ),
+)
+
+logicalvolume_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:logicalvolume_list",
+    link_text="Logical Volume",
+    permissions=["netbox_storage.disk_view"],
+    buttons=(
+        PluginMenuButton(
+            "plugins:netbox_storage:logicalvolume_add",
+            "Add",
+            "mdi mdi-plus-thick",
+            ButtonColorChoices.GREEN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+        PluginMenuButton(
+            "plugins:netbox_storage:logicalvolume_import",
+            "Import",
+            "mdi mdi-upload",
+            ButtonColorChoices.CYAN,
+            permissions=["netbox_storage.add_disk"],
+        ),
+    ),
+)
+
 menu = PluginMenu(
     label="NetBox Storage",
     groups=(
@@ -120,9 +142,10 @@ menu = PluginMenu(
             "Volume Configuration",
             (
                 filesystem_menu_item,
-                linuxvolume_menu_item,
+                logicalvolume_menu_item,
+                volumegroup_menu_item,
                 partition_menu_item,
-                physicalvolume_menu_item
+                physicalvolume_menu_item,
             ),
         ),
         (
